@@ -1,17 +1,20 @@
-from celery.task import Task
+from django.conf import settings
 from django.core.mail import get_connection
 
-CELERY_EMAIL_BACKEND = getattr(settings, 'CELERY_EMAIL_BACKEND',
-                               'django.core.mail.backends.smtp.EmailBackend')
+from celery.task import Task
+
+
+CONFIG = getattr(settings, 'CELERY_EMAIL_TASK_CONFIG', {})
+BACKEND = getattr(settings, 'CELERY_EMAIL_BACKEND',
+                  'django.core.mail.backends.smtp.EmailBackend')
 
 
 class SendEmailTask(Task):
-    #default_retry_delay = 60 * 5
     ignore_result = True
     
     def run(self, message, **kwargs):
         logger = self.get_logger(**kwargs)
-        conn = get_connection(backend=CELERY_EMAIL_BACKEND)
+        conn = get_connection(backend=BACKEND)
         try:
             conn.send_messages([message])
             logger.debug("Successfully sent email message to %r.", message.to)
@@ -24,4 +27,7 @@ class SendEmailTask(Task):
                             message.to)
             except self.MaxRetriesExceededError:
                 logger.error("Max retries exceeded trying to send email to %r.",
-                             message.to)
\ No newline at end of file
+                             message.to)
+
+for key, val in CONFIG.iteritems():
+    setattr(SendEmailTask, key, val)
\ No newline at end of file
